@@ -90,3 +90,8 @@ void ui_classic_view_create();
 void ui_classic_view_destroy();
 void ui_paper_view_create();
 void ui_paper_view_destroy();
+
+#ifdef WITH_HILDON
+void create_hildon_menu (HildonWindow *main_window);
+#endif
+
